'use strict';

exports.__esModule = true;
exports.run = run;
exports.init = init;
exports.remove = remove;

var _arrayIncludes = require('array-includes');

var _arrayIncludes2 = _interopRequireDefault(_arrayIncludes);

var _processes = require('./processes');

var processes = _interopRequireWildcard(_processes);

var _fs = require('../utils/fs');

var fs = _interopRequireWildcard(_fs);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function run(pkg, script, args = []) {
  let spawnArgs = ['run', '-s', script];

  if (args.length) {
    spawnArgs = spawnArgs.concat('--', args);
  }

  let validScript = false;
  let scripts = pkg.config.getScripts();

  if (scripts && scripts[script]) {
    validScript = true;
  }

  if (!validScript) {
    let bins = await fs.readdirSafe(pkg.nodeModulesBin);

    if ((0, _arrayIncludes2.default)(bins, script)) {
      validScript = true;
    }
  }

  if (validScript) {
    await processes.spawn('yarn', spawnArgs, {
      cwd: pkg.dir,
      pkg: pkg,
      tty: true
    });
  }

  return validScript;
}
async function init(cwd) {
  await processes.spawn('yarn', ['init', '-s'], {
    cwd: cwd,
    tty: true
  });
}

async function remove(dependencies, cwd) {
  await processes.spawn('yarn', ['remove', ...dependencies], {
    cwd,
    tty: true
  });
}